/*
 * Copyright (c) 2009, Morten Nobel-Jrgensen All Rights Reserved.
 *
 * GNU General Public License, version 2
 * http://www.gnu.org/licenses/gpl-2.0.txt
 *
 */

package com.mortennobel.easizer.gui;

import com.mortennobel.easizer.Easizer;
import com.mortennobel.easizer.i18n.EasizerTextConstants;

import javax.swing.*;
import javax.swing.border.EmptyBorder;
import javax.swing.event.HyperlinkEvent;
import javax.swing.event.HyperlinkListener;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;

public class EasizerAbout extends JDialog implements HyperlinkListener, ActionListener {

	public EasizerAbout(Frame owner, String title, boolean modal) {
		super(owner, title, modal);
		JEditorPane editorPane = new JEditorPane("text/html","<html><b>"+EasizerTextConstants.getString("EasizerVersion")+" "+ Easizer.VERSION+"</b>" +
				"<br>"+EasizerTextConstants.getString("DevelopedBy")+": Morten Nobel-Joergensen<br><a href=\"http://www.nobel-joergensen.com/\">http://www.nobel-joergensen.com/</a><br>" +
				"<a href=\"mailto:morten@nobel-joergensen.com\">morten@nobel-joergensen.com</a><br><br>" +
				EasizerTextConstants.getString("License")+": <a href=\"http://www.gnu.org/licenses/gpl-2.0.txt\">GNU General Public License, version 2</a>");
		editorPane.setEditable(false);
		editorPane.setOpaque(false);
		editorPane.setBorder(new EmptyBorder(10,10,10,10));
		editorPane.addHyperlinkListener(this);
		Container contentPane = getContentPane();
		contentPane.setLayout(new BorderLayout(15,15));
		
		contentPane.add(editorPane, BorderLayout.CENTER);
		JLabel iconLabel = new JLabel(new ImageIcon(getClass().getResource("/images/icon64.png")));
		iconLabel.setBorder(new EmptyBorder(0,10,0,0));
		contentPane.add(iconLabel, BorderLayout.WEST);

		JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.CENTER));
		contentPane.add(buttonPanel, BorderLayout.SOUTH);
		JButton closeButton = new JButton(EasizerTextConstants.getString("AboutDialogClose"));
		buttonPanel.add(closeButton);
		closeButton.addActionListener(this);
	}

	public static void show(JFrame owner) {
		EasizerAbout about = new EasizerAbout(owner, "Easizer", true);
		about.pack();
		if (owner!=null){
			about.setLocation(owner.getLocation());
		}
		about.setVisible(true);
	}

	public void hyperlinkUpdate(HyperlinkEvent e) {
		if (e.getEventType() == HyperlinkEvent.EventType.ACTIVATED && Desktop.isDesktopSupported()) {
			try {
				String url = e.getURL().toExternalForm();
				if (url.startsWith("mailto")){
					Desktop.getDesktop().mail(new URI(url));
				}
				else{
					Desktop.getDesktop().browse(new URI(url));
				}

			} catch (IOException e1) {
				e1.printStackTrace();
			} catch (URISyntaxException e1) {
				e1.printStackTrace();
			}
		}
	}

	public void actionPerformed(ActionEvent e) {
		dispose();
	}
}
