/*
 * Copyright (c) 2009, Morten Nobel-Jrgensen All Rights Reserved.
 *
 * GNU General Public License, version 2
 * http://www.gnu.org/licenses/gpl-2.0.txt
 *
 */

package com.mortennobel.easizer.gui;

import static com.mortennobel.easizer.i18n.EasizerTextConstants.getString;
import com.mortennobel.easizer.model.GUISetup;
import com.mortennobel.easizer.model.ResizeConfiguration;
import net.iharder.dnd.FileDrop;
import org.jdesktop.application.LocalStorage;
import org.jdesktop.application.SingleFrameApplication;

import javax.imageio.ImageIO;
import javax.swing.*;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.InputStream;
import java.io.ObjectInputStream;
import java.util.ArrayList;
import java.util.List;

public class EasizerGUI extends SingleFrameApplication {
    JMenuBar menuBar = new JMenuBar();
    JMenu fileMenu = new JMenu(getString("MenuFile"));

    JMenu windowMenu = new JMenu(getString("MenuWindow"));
    JMenuItem settings = new JMenuItem(getString("MenuFileSettings"));
    JMenuItem exit = new JMenuItem(getString("MenuFileExit"));
    JMenuItem alwaysOnTop = new JCheckBoxMenuItem(getString("MenuWindowAllwaysOnTop"));

    JMenu helpMenu = new JMenu(getString("MenuHelp"));
    JMenuItem helpTopics = new JMenuItem(getString("MenuHelpTopics"));
    JMenuItem about = new JMenuItem(getString("MenuHelpAbout"));

    private EasizerController controller;
    private ResizeConfigurationGUI resizeConfigGUI;

    protected void initialize(String[] args) {
		super.initialize(args);
        GUISetup guiSetup;
        ResizeConfiguration config;
        LocalStorage localStorage = getContext().getLocalStorage();
        try{
            InputStream is = localStorage.openInputFile(".easizer.gui");
            ObjectInputStream ois = new ObjectInputStream(is);
            guiSetup = (GUISetup) ois.readObject();
            config = (ResizeConfiguration) ois.readObject();
            ois.close();
            is.close();
        }
        catch (Exception e){
            guiSetup = new GUISetup();
            config = new  ResizeConfiguration();
        }
        controller = new EasizerController(this, guiSetup, config);
    }

    @Override
    protected void startup() {
        super.startup();
        getMainTopLevel().setTitle(getString("ProgramTitle"));

        getMainTopLevel().setIconImages(getWindowIcons());

        if (controller.getGuiSetup().isAlwaysOnTop()){
            if (getMainTopLevel().isAlwaysOnTopSupported()){
                alwaysOnTop.setSelected(true);
                getMainTopLevel().setAlwaysOnTop(true);
            }
            else{
                alwaysOnTop.setEnabled(false);
            }
        }
    }

    private List<? extends Image> getWindowIcons() {
        java.util.List<BufferedImage> imageList = new ArrayList<BufferedImage>();
        int[] sizes = new int[]{10,16,20,24,30,50,64};
        for (int size:sizes){
            try{
                BufferedImage image = ImageIO.read(getClass().getResource("/images/icon"+size+".png"));
                imageList.add(image);
            }
            catch (Exception e){
                e.printStackTrace();
            }
        }
        return imageList;
    }

    @Override
    protected void shutdown() {
        controller.setConfiguration(resizeConfigGUI.getResizeConfiguration());
		controller.saveSettings();

        super.shutdown();
    }

    protected JMenuBar createJMenuBar() {
        menuBar.add(fileMenu);
        menuBar.add(windowMenu);
        menuBar.add(helpMenu);

        exit.addActionListener(controller);
		settings.addActionListener(controller);
		fileMenu.add(settings);
        fileMenu.addSeparator();
        fileMenu.add(exit);

        alwaysOnTop.addActionListener(controller);
        windowMenu.add(alwaysOnTop);

        if (Desktop.isDesktopSupported()) {
            helpTopics.addActionListener(controller);
        }
		helpMenu.add(helpTopics);
		about.addActionListener(controller);
        helpMenu.add(about);

        return menuBar;
    }

    @Override
    protected Component createMainComponent() {
        assert(controller!=null);
        JPanel rootPanel = new JPanel(new BorderLayout());
		JScrollPane scrollPane = new JScrollPane(getShortConfig(), JScrollPane.VERTICAL_SCROLLBAR_NEVER, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
		rootPanel.add(scrollPane, BorderLayout.NORTH);
        rootPanel.add(getDropBox(), BorderLayout.CENTER);

        return rootPanel;
    }

    private Component getShortConfig() {
        return resizeConfigGUI = new ResizeConfigurationGUI(controller.getConfiguration());
    }

    private JComponent getDropBox() {
        EasizerDropBoxPanel panel = new EasizerDropBoxPanel();
        Dimension dim = new Dimension(300,300);
        panel.setPreferredSize(dim);
        panel.setMinimumSize(dim);
        new  FileDrop( panel, controller);
        return panel;
    }

    public ResizeConfiguration getResizeConfiguration() {
        return resizeConfigGUI.getResizeConfiguration();
    }
}





































