/*
 * Copyright (c) 2009, Morten Nobel-Jrgensen All Rights Reserved.
 *
 * GNU General Public License, version 2
 * http://www.gnu.org/licenses/gpl-2.0.txt
 *
 */

package com.mortennobel.easizer.gui;

import static com.mortennobel.easizer.i18n.EasizerTextConstants.getString;

import javax.swing.*;
import java.awt.*;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

public class EasizerProgressMonitor extends ProgressMonitor implements PropertyChangeListener {
    private final EasizerController.ResizeTask resizeTask;


    /**
     * Constructs a graphic object that shows progress, typically by filling
     * in a rectangular bar as the process nears completion.
     *
     * @param parentComponent the parent component for the dialog box
     * @see javax.swing.JDialog
     * @see javax.swing.JOptionPane
     */
    public EasizerProgressMonitor(Component parentComponent, EasizerController.ResizeTask resizeTask) {
        super(parentComponent, getString("ResizingDialogTitle"), "", 0, 100);
        this.resizeTask = resizeTask;
		String maxPossibleString = String.format("%d/%d %s - (%d%%)", resizeTask.getNumberOfFiles(),resizeTask.getNumberOfFiles(), resizeTask.getLongestFilename(),100);
		setNote(maxPossibleString);
		resizeTask.addPropertyChangeListener(this);
        setMillisToDecideToPopup(0);
        setMillisToPopup(0);

	}

    public void propertyChange(PropertyChangeEvent evt) {
		if ("progress".equals(evt.getPropertyName())) {
            int progress = (Integer) evt.getNewValue();
            setNode(progress);
        }
    }

    private void setNode(int progress){
        setProgress(progress);

		String message;
		if (resizeTask.getNumberOfFiles()>1){
			message = String.format("%d/%d %s - (%d%%)", resizeTask.getCurrentFileIndex()+1,resizeTask.getNumberOfFiles(), resizeTask.getCurrentFile(),progress);
		}
		else {
			message = String.format("%s - (%d%%)", resizeTask.getCurrentFile(),progress);
		}
		setNote(message);
	}
}
