/*
 * Copyright (c) 2009, Morten Nobel-Jrgensen All Rights Reserved.
 *
 * GNU General Public License, version 2
 * http://www.gnu.org/licenses/gpl-2.0.txt
 *
 */

package com.mortennobel.easizer.gui;

import static com.mortennobel.easizer.i18n.EasizerTextConstants.getString;
import com.mortennobel.easizer.model.ResizeConfiguration;

import javax.swing.*;
import javax.swing.border.EmptyBorder;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.text.DefaultFormatterFactory;
import javax.swing.text.NumberFormatter;
import java.awt.*;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.text.DecimalFormat;

public class ResizeConfigurationGUI extends JPanel {

    static JFormattedTextField.AbstractFormatterFactory ff;
    static{
        DecimalFormat format = new DecimalFormat();
        format.setDecimalSeparatorAlwaysShown(false);
        format.setGroupingUsed(false);

        JFormattedTextField.AbstractFormatter formatter    = new NumberFormatter( format );
        ff = new DefaultFormatterFactory( formatter, formatter, formatter);
    }

    private JCheckBox maxDimensionChecked = new JCheckBox("");
    private JLabel maxDimensionLabel = new JLabel(getString("OptionsMaxDimension"));
    private JTextField maxWidth = new JFormattedTextField(ff,200);
    private JLabel xLabelPixels = new JLabel("x");
    private JTextField maxHeight = new JFormattedTextField(ff, 300);
    private JLabel pixelsLabelPixels = new JLabel(" "+getString("OptionsPixels"));
    private JCheckBox maxFileSizeChecked = new JCheckBox("");
    private JLabel maxFileSizeLabel = new JLabel(getString("OptionsMaxFileSize"));

    private JTextField maxFileSize = new JFormattedTextField(ff, 300);
    private JComboBox maxFileSizeUnit = new JComboBox(ResizeConfiguration.FileSizeUnit.values());

    private JRadioButton overwriteRadioButton = new JRadioButton(getString("OptionsOverwriteFile"));
    private JRadioButton renameRadioButton = new JRadioButton(getString("OptionsNewCopyFile"));

    private ButtonGroup buttonGroup = new ButtonGroup();
	private ResizeConfiguration resizeConfiguration;

	public ResizeConfigurationGUI(ResizeConfiguration resizeConfiguration) {
        super(new GridLayout(0,1,0,7));
		this.resizeConfiguration = resizeConfiguration;
		setBorder(new EmptyBorder(7,0,7,0));
        Dimension prefTextFieldSize = maxWidth.getPreferredSize();
        prefTextFieldSize = new Dimension((int)(prefTextFieldSize.width*1.5), prefTextFieldSize.height);
        maxWidth.setPreferredSize(prefTextFieldSize);
        maxHeight.setPreferredSize(prefTextFieldSize);
        maxFileSize.setPreferredSize(prefTextFieldSize);

        maxWidth.setHorizontalAlignment(JTextField.RIGHT);
        maxHeight.setHorizontalAlignment(JTextField.RIGHT);
        maxFileSize.setHorizontalAlignment(JTextField.RIGHT);

        setResizeConfiguration(resizeConfiguration);

        initLayout();
    }

    public void setResizeConfiguration(ResizeConfiguration resizeConfiguration) {
        maxDimensionChecked.setSelected(resizeConfiguration.isMaxDimension());
        maxWidth.setText(String.valueOf(resizeConfiguration.getMaxWidth()));
        maxHeight.setText(String.valueOf(resizeConfiguration.getMaxHeight()));

        maxFileSizeChecked.setSelected(resizeConfiguration.isMaxFileSize());
        maxFileSize.setText(String.valueOf(resizeConfiguration.getFileSize()));
        maxFileSizeUnit.setSelectedItem(resizeConfiguration.getFileSizeUnit());

        overwriteRadioButton.setSelected(resizeConfiguration.overwriteFile());
        renameRadioButton.setSelected(!resizeConfiguration.overwriteFile());
    }

    private void initLayout() {
        JPanel row1 = new JPanel(new FlowLayout(FlowLayout.LEFT,3,0));
        row1.add(maxDimensionChecked);
        row1.add(maxDimensionLabel);
        row1.add(maxWidth);
        row1.add(xLabelPixels);
        row1.add(maxHeight);
        row1.add(pixelsLabelPixels);

        maxDimensionLabel.addMouseListener(new MouseAdapter() {
            public void mouseClicked(MouseEvent e) {
                maxDimensionChecked.setSelected(!maxDimensionChecked.isSelected());
                updateEnabledStatus();
            }
        });

        maxFileSizeLabel.addMouseListener(new MouseAdapter() {
            public void mouseClicked(MouseEvent e) {
                maxFileSizeChecked.setSelected(!maxFileSizeChecked.isSelected());
                updateEnabledStatus();
            }
        });

        JPanel row2 = new JPanel(new FlowLayout(FlowLayout.LEFT,3,0));
        row2.add(maxFileSizeChecked);
        row2.add(maxFileSizeLabel);
        row2.add(maxFileSize);
        row2.add(maxFileSizeUnit);

        JPanel row3 = new JPanel(new FlowLayout(FlowLayout.LEFT,3,0));
        row3.add(overwriteRadioButton);
        row3.add(renameRadioButton);

        buttonGroup.add(overwriteRadioButton);
        buttonGroup.add(renameRadioButton);

        add(row1);
        add(row2);
        add(row3);

        ChangeListener checkboxChanged = new ChangeListener() {
            public void stateChanged(ChangeEvent e) {
                updateEnabledStatus();
            }
        };

        maxDimensionChecked.addChangeListener(checkboxChanged);
        maxFileSizeChecked.addChangeListener(checkboxChanged);

        updateEnabledStatus();
    }

    private void updateEnabledStatus(){
        boolean maxDimensionEnabled = maxDimensionChecked.isSelected();
        maxDimensionLabel.setEnabled(maxDimensionEnabled);
        maxWidth.setEnabled(maxDimensionEnabled);
        xLabelPixels.setEnabled(maxDimensionEnabled);
        maxHeight.setEnabled(maxDimensionEnabled);
        pixelsLabelPixels.setEnabled(maxDimensionEnabled);

        boolean maxFileSizeSelected = maxFileSizeChecked.isSelected();
        maxFileSizeLabel.setEnabled(maxFileSizeSelected);
        maxFileSize.setEnabled(maxFileSizeSelected);
        maxFileSizeUnit.setEnabled(maxFileSizeSelected);
    }

    public ResizeConfiguration getResizeConfiguration(){
		resizeConfiguration.setMaxDimension(maxDimensionChecked.isSelected());
		resizeConfiguration.setMaxWidth(Integer.parseInt(maxWidth.getText()));
		resizeConfiguration.setMaxHeight(Integer.parseInt(maxHeight.getText()));
		resizeConfiguration.setMaxFileSize(maxFileSizeChecked.isSelected());
		resizeConfiguration.setFileSize(Integer.parseInt(maxFileSize.getText()));
		resizeConfiguration.setFileSizeUnit((ResizeConfiguration.FileSizeUnit) maxFileSizeUnit.getSelectedItem());
		resizeConfiguration.setOverwriteFile(overwriteRadioButton.isSelected());

		return resizeConfiguration;
    }

	
}
