/*
 * Copyright (c) 2009, Morten Nobel-Jrgensen All Rights Reserved.
 *
 * GNU General Public License, version 2
 * http://www.gnu.org/licenses/gpl-2.0.txt
 *
 */

package com.mortennobel.easizer.model;

import com.mortennobel.imagescalingframework.*;

import java.awt.*;

public enum ResizeAlgorithm{
	Bell,
	BiCubic,
	BiCubicHighFreq,
	Box,
	BSpline,
	Hermite,
	Lanczos3,
	Mitchell,
	Triangle,
	BiCubicMultistep,
	BilinearMultistep;

	public AdvancedResizeOp getResizeAlgorithm(int width, int height, boolean unsharpenFilter){
		AdvancedResizeOp res;
		switch(this){
			case BiCubicMultistep:
			case BilinearMultistep:
				Object renderingHint = this==BilinearMultistep? RenderingHints.VALUE_INTERPOLATION_BILINEAR:RenderingHints.VALUE_INTERPOLATION_BICUBIC;
				res = new MultiStepRescaleOp(width, height, renderingHint);
				break;
			default:
				ResampleOp resOp = new ResampleOp(width, height);
				ResampleFilter resampleFilter;
				switch (this){
					case Bell:
						resampleFilter = new BellFilter();
						break;
					case BiCubic:
						resampleFilter = new BiCubicFilter();
						break;
					case BiCubicHighFreq:
						resampleFilter = new BiCubicHighFreqResponse();
						break;
					case Box:
						resampleFilter = new BoxFilter();
						break;
					case BSpline:
						resampleFilter = new BSplineFilter();
						break;
					case Hermite:
						resampleFilter = new HermiteFilter();
						break;
					case Lanczos3:
						resampleFilter = new Lanczos3Filter();
						break;
					case Mitchell:
						resampleFilter = new MitchellFilter();
						break;
					case Triangle:
					default:
						resampleFilter = new TriangleFilter();
						break;
				}
				resOp.setFilter(resampleFilter);
				res = resOp;
		}
		res.setUnsharpenFilterAfterReduce(unsharpenFilter);
		return res;
	}


	public String toString() {
		switch (this){
			case Bell:
				return "Bell";
			case BiCubic:
				return "Bi Cubic";
			case BiCubicHighFreq:
				return "BiCubic High Freq";
			case BiCubicMultistep:
				return "BiCubic Multistep";
			case BilinearMultistep:
				return "Bilinear Multistep";
			case Box:
				return "Box";
			case BSpline:
				return "BSpline";
			case Hermite:
				return "Hermite";
			case Lanczos3:
				return "Lanczos3";
			case Mitchell:
				return "Mitchell";
			case Triangle:
			default:
				return "Triangle";
		}
	}
}